==> developer-center-api-1.7.7-20170223.072418-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppLayoutBrickDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by liuyao on 16/7/27.
 */
public class AppLayoutBrickDto implements Serializable {
    private static final long serialVersionUID = 4245863213891717930L;
    public static final int STATUS_HIDDEN = 0;
    public static final int STATUS_SHOW = 1;

    public static final int IMAGE_STYLE_DEFAUL = 0;
    public static final int IMAGE_STYLE_WHITE = 1;

    private Long id;
    private Long appId;
    private String name;
    private String md5;
    private Integer payload;
    private Integer position;
    private String image;
    private Integer deleted;
    private Integer status;
    private Integer imageStyle;
    private Date gmtCreate;
    private Date gmtModified;

    //附加字段
    private Boolean isNew;
    private Long appCount;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getMd5() {
        return md5;
    }

    public void setMd5(String md5) {
        this.md5 = md5;
    }

    public Integer getPayload() {
        return payload;
    }

    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    public Integer getPosition() {
        return position;
    }

    public void setPosition(Integer position) {
        this.position = position;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getImageStyle() {
        return imageStyle;
    }

    public void setImageStyle(Integer imageStyle) {
        this.imageStyle = imageStyle;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getAppCount() {
        return appCount;
    }

    public void setAppCount(Long appCount) {
        this.appCount = appCount;
    }

    public Boolean getNew() {
        return isNew;
    }

    public void setNew(Boolean aNew) {
        isNew = aNew;
    }
}

==> developer-center-api-3.9.1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppLayoutBrickDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by liuyao on 16/7/27.
 */
public class AppLayoutBrickDto implements Serializable {
    private static final long serialVersionUID = 4245863213891717930L;
    public static final int STATUS_HIDDEN = 0;
    public static final int STATUS_SHOW = 1;

    public static final int IMAGE_STYLE_DEFAUL = 0;
    public static final int IMAGE_STYLE_WHITE = 1;

    private Long id;
    private Long appId;
    private String name;
    private String md5;
    private Integer payload;
    private Integer position;
    private String image;
    private Integer deleted;
    private Integer status;
    private Integer imageStyle;
    private Date gmtCreate;
    private Date gmtModified;
    private String content;

    //附加字段
    private Boolean isNew;
    private Long appCount;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getMd5() {
        return md5;
    }

    public void setMd5(String md5) {
        this.md5 = md5;
    }

    public Integer getPayload() {
        return payload;
    }

    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    public Integer getPosition() {
        return position;
    }

    public void setPosition(Integer position) {
        this.position = position;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getImageStyle() {
        return imageStyle;
    }

    public void setImageStyle(Integer imageStyle) {
        this.imageStyle = imageStyle;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getAppCount() {
        return appCount;
    }

    public void setAppCount(Long appCount) {
        this.appCount = appCount;
    }

    public Boolean getNew() {
        return isNew;
    }

    public void setNew(Boolean aNew) {
        isNew = aNew;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
}
